.. Copyright (c) 2018-2020 mudpy authors. Permission to use, copy,
   modify, and distribute this software is granted under terms
   provided in the LICENSE file distributed with this software.

.. title:: about
.. meta::
   :description: The mudpy MUD server engine.
   :keywords: Multi-User Dungeon, MUD, Role-Playing, Game, Telnet,
              Text, Python, Free Software, Open Source, Libre, FLOSS

.. include:: ../../README

.. toctree::
   :hidden:
   :maxdepth: 2

   admin
   api
   changelog
   clients
   coder
   configuration
   data_model
   install
   license

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
